@@ -3,24 +3,20 @@ package HTML::FormFu::Attribute;
 use strict;
 use Exporter qw/ import /;
 use HTML::FormFu::Util qw/
-    append_xml_attribute remove_xml_attribute literal require_class
+    append_xml_attribute remove_xml_attribute literal
     _parse_args /;
-use List::MoreUtils qw/ uniq /;
-use Scalar::Util qw/ weaken /;
-use Carp qw/ croak /;
 
 our @EXPORT_OK = qw/ mk_attrs mk_attr_accessors mk_attr_modifiers
-    mk_add_methods mk_single_methods mk_require_methods mk_get_methods
-    mk_get_one_methods mk_inherited_accessors mk_output_accessors 
+    mk_inherited_accessors mk_output_accessors
     mk_inherited_merging_accessors mk_accessors /;
 
 sub mk_accessors {
     my $class = shift;
 
     for my $name (@_) {
-        my$sub = sub {
+        my $sub = sub {
             my $self = shift;
-    
+
             if ( @_ == 1 ) {
                 $self->{$name} = $_[0];
                 return $self;
@@ -33,9 +29,9 @@ sub mk_accessors {
                 return $self->{$name};
             }
         };
-        
+
         no strict 'refs';
-        *{"$class\::$name"} = $sub
+        *{"$class\::$name"} = $sub;
     }
 }
 
@@ -207,193 +203,6 @@ sub mk_del_attrs {
     return;
 }
 
-sub mk_add_methods {
-    my ( $self, @names ) = @_;
-
-    my $class = ref $self || $self;
-
-    for my $name (@names) {
-        my $sub = sub {
-            my ( $self, $arg ) = @_;
-            my @return;
-            my $sub_name = "_single_$name";
-
-            if ( ref $arg eq 'ARRAY' ) {
-                push @return, map { $self->$sub_name($_) } @$arg;
-            }
-            else {
-                push @return, $self->$sub_name($arg);
-            }
-
-            return @return == 1 ? $return[0] : @return;
-        };
-
-        no strict 'refs';
-
-        *{"$class\::$name"} = $sub;
-    }
-
-    return;
-}
-
-sub mk_single_methods {
-    my ( $self, @names ) = @_;
-
-    my $class = ref $self || $self;
-
-    for my $name (@names) {
-        my $sub = sub {
-            my ( $self, $arg ) = @_;
-            my @items;
-
-            if ( ref $arg eq 'HASH' ) {
-                push @items, $arg;
-            }
-            elsif ( !ref $arg ) {
-                push @items, { type => $arg };
-            }
-            else {
-                croak 'invalid args';
-            }
-
-            my @return;
-
-            for my $item (@items) {
-                my @names = map { ref $_ ? @$_ : $_ }
-                    grep {defined}
-                    ( delete $item->{name}, delete $item->{names} );
-
-                @names = uniq map { $_->name }
-                    grep { defined $_->name } @{ $self->get_fields }
-                    if !@names;
-
-                croak "no field names to add $name to" if !@names;
-
-                my $type = delete $item->{type};
-
-                for my $x (@names) {
-                    my $require_sub  = "_require_$name";
-                    my $array_method = "_${name}s";
-
-                    for my $field ( @{ $self->get_fields( { name => $x } ) } ) {
-                        my $new = $field->$require_sub( $type, $item );
-                        push @{ $field->$array_method }, $new;
-                        push @return, $new;
-                    }
-                }
-            }
-
-            return @return;
-        };
-
-        no strict 'refs';
-
-        *{"$class\::_single_$name"} = $sub;
-    }
-
-    return;
-}
-
-sub mk_require_methods {
-    my ( $self, @names ) = @_;
-
-    my $class = ref $self || $self;
-
-    for my $name (@names) {
-        my $sub = sub {
-            my ( $self, $type, $opt ) = @_;
-
-            croak 'required arguments: $self, $type, \%options' if @_ != 3;
-
-            eval { my %x = %$opt };
-            croak "options argument must be hash-ref" if $@;
-
-            my $class = $type;
-            if ( not $class =~ s/^\+// ) {
-                $class = "HTML::FormFu::" . ucfirst($name) . "::$class";
-            }
-
-            $type =~ s/^\+//;
-
-            require_class($class);
-
-            my $object = $class->new( {
-                    type   => $type,
-                    parent => $self,
-                } );
-
-            # inlined ObjectUtil::populate(), otherwise circular dependency
-            eval {
-                map { $object->$_( $opt->{$_} ) } keys %$opt;
-            };
-            croak $@ if $@;
-
-            return $object;
-        };
-
-        no strict 'refs';
-
-        *{"$class\::_require_$name"} = $sub;
-    }
-
-    return;
-}
-
-sub mk_get_methods {
-    my ( $self, @names ) = @_;
-
-    my $class = ref $self || $self;
-
-    for my $name (@names) {
-        my $sub = sub {
-            my $self       = shift;
-            my %args       = _parse_args(@_);
-            my $get_method = "get_${name}s";
-
-            my @x = map { @{ $_->$get_method(@_) } } @{ $self->_elements };
-
-            if ( exists $args{name} ) {
-                @x = grep { $_->name eq $args{name} } @x;
-            }
-
-            if ( exists $args{type} ) {
-                @x = grep { $_->type eq $args{type} } @x;
-            }
-
-            return \@x;
-        };
-
-        no strict 'refs';
-
-        *{"$class\::get_${name}s"} = $sub;
-    }
-
-    return;
-}
-
-sub mk_get_one_methods {
-    my ( $self, @names ) = @_;
-
-    my $class = ref $self || $self;
-
-    for my $name (@names) {
-        my $sub = sub {
-            my $self       = shift;
-            my $get_method = "get_${name}s";
-
-            my $x = $self->$get_method(@_);
-
-            return @$x ? $x->[0] : ();
-        };
-
-        no strict 'refs';
-
-        *{"$class\::get_$name"} = $sub;
-    }
-
-    return;
-}
-
 sub mk_inherited_accessors {
     my ( $self, @names ) = @_;
 
