@@ -21,6 +21,9 @@ sub process {
     my ( $self, $params ) = @_;
     my $count = 0;
 
+    # check when condition
+    return unless $self->_process_when( $params );
+
     # others are needed
     my $others = $self->others;
     return if !defined $others;
@@ -29,7 +32,7 @@ sub process {
     my $min = $self->minimum;
     $min = 1 if !defined $min;
     my $max = $self->maximum;
-    $max = 1 if !defined $max;
+    $max = 1 + scalar @$others if !defined $max;
 
     # get field names to check
     my @names = ( $self->name );
@@ -107,6 +110,9 @@ The maximum number of named fields which must be filled in.
 
 L</max> is an alias for L</maximum>.
 
+The default for max is the number of all affected fields, in other words one
+more than the number of elements given to others.
+
 =head2 attach_errors_to_base
 
 Default Value: 1
