@@ -4,14 +4,10 @@ use strict;
 use base 'HTML::FormFu::Element';
 use Class::C3;
 
-use HTML::FormFu::Attribute qw/
-    mk_add_methods mk_single_methods mk_require_methods mk_get_methods
-    mk_get_one_methods mk_output_accessors /;
+use HTML::FormFu::Attribute qw/ mk_output_accessors /;
 use HTML::FormFu::ObjectUtil qw/
-    _single_element _require_constraint
-    get_fields get_field get_errors get_error clear_errors
-    get_elements get_element get_all_elements get_all_element insert_before
-    insert_after /;
+    :FORM_AND_BLOCK
+    insert_before insert_after /;
 use HTML::FormFu::Util qw/ _get_elements xml_escape /;
 use Storable qw( dclone );
 use Carp qw/croak/;
@@ -26,31 +22,6 @@ __PACKAGE__->mk_inherited_accessors(
         auto_transformer_class render_processed_value force_errors /
 );
 
-__PACKAGE__->mk_add_methods(
-    qw/
-        element deflator filter constraint inflator valiBdator transformer /
-);
-
-__PACKAGE__->mk_single_methods(
-    qw/
-        deflator constraint filter inflator validator transformer /
-);
-
-__PACKAGE__->mk_require_methods(
-    qw/
-        deflator filter inflator validator transformer /
-);
-
-__PACKAGE__->mk_get_methods(
-    qw/
-        deflator filter constraint inflator validator transformer /
-);
-
-__PACKAGE__->mk_get_one_methods(
-    qw/
-        deflator filter constraint inflator validator transformer /
-);
-
 *elements     = \&element;
 *constraints  = \&constraint;
 *deflators    = \&deflator;
