@@ -1,15 +1,15 @@
 package HTML::FormFu::Filter::CopyValue;
 
-use Moose;
-extends 'HTML::FormFu::Filter';
+use strict;
+use base 'HTML::FormFu::Filter';
 
-has field => ( is => 'rw', traits => ['Chained'] );
+__PACKAGE__->mk_accessors(qw/ field /);
 
 sub filter {
     my ( $self, $value ) = @_;
 
     return $value
-        if ( defined $value && length $value );
+        if (defined $value && length $value);
 
     my $field_name = $self->field
         or die "Parameter 'field' is not defined.";
@@ -17,20 +17,18 @@ sub filter {
     my $parent = $self->parent
         or die "Can't determine my parent.";
 
-    my $field_value = $parent->form->input->{$field_name};
+    my $field_value = $parent->form->input->{ $field_name };
 
     return $field_value;
 }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 
 __END__
 
 =head1 NAME
 
-HTML::FormFu::Filter::CopyValue - copy the value from another field
+HTML::FormFu::Filter::CopyValue - copy the value from an other field
 
 =head1 SYNOPSIS
 
@@ -50,10 +48,12 @@ is empty.
 
 =head1 CAVEATS
 
-If the original field contains an invalid value (a value that will be
-constrained through a constraint) that invalid value will be copied to this
-field (the field with the CopyValue filter).  So, the user has to change two
-fields, or you can remove the invalid value in a custom constraint.
+If the value of the original field contains an invalid value (a value that
+will be constrained through a constraint) this invalid value will be choosen
+for this field (the field with CopyValue filter).
+
+So the user has to change two fields or you remove the invalid value in a
+custom constraint.
 
 =head1 AUTHOR
 
