@@ -1,43 +1,44 @@
 package HTML::FormFu::OutputProcessor::StripWhitespace;
 
-use Moose;
-extends 'HTML::FormFu::OutputProcessor';
+use strict;
+use base 'HTML::FormFu::OutputProcessor';
 
-use HTML::FormFu::Constants qw( $EMPTY_STR );
+use HTML::FormFu::Attribute(qw/ mk_accessors /);
 use HTML::TokeParser::Simple;
-use List::MoreUtils qw( any );
 
-has collapse_tags => (
-    is      => 'rw',
-    default => sub {
-        [ qw(
-            fieldset
-            form
-            hr
-            legend
-            optgroup
-            option
-            table
-            td
-            th
-            tr
-        ) ]
-    },
-    lazy    => 1,
-    traits  => ['Chained'],
+__PACKAGE__->mk_accessors(
+    qw/
+        collapse_tags
+        collapse_consecutive_tags
+        /
 );
 
-has collapse_consecutive_tags => (
-    is      => 'rw',
-    default => sub {
-        [ qw(
-            span
-            div
-        ) ]
-    },
-    lazy    => 1,
-    traits  => ['Chained'],
-);
+sub new {
+    my $self = shift->next::method(@_);
+
+    $self->collapse_tags( [
+            qw/
+                fieldset
+                form
+                hr
+                legend
+                optgroup
+                option
+                table
+                td
+                th
+                tr
+                /
+        ] );
+
+    $self->collapse_consecutive_tags( [
+            qw/
+                span
+                /
+        ] );
+
+    return $self;
+}
 
 sub process {
     my ( $self, $input ) = @_;
@@ -50,11 +51,11 @@ sub process {
     }
 
     my $iter
-        = HTML::FormFu::OutputProcessor::StripWhitespace::_iter->new(@tokens);
+        = HTML::FormFu::OutputProcessor::StripWhitespace::_iter->new( @tokens );
 
     my @collapse    = @{ $self->collapse_tags };
     my @consecutive = @{ $self->collapse_consecutive_tags };
-    my $output      = $EMPTY_STR;
+    my $output      = "";
 
     while ( defined( my $token = $iter->next ) ) {
 
@@ -62,7 +63,7 @@ sub process {
             my $tag      = $token->get_tag;
             my $prev_tag = $iter->prev_tag_name;
 
-            if ( any { $tag eq $_ } @collapse ) {
+            if ( grep { $tag eq $_ } @collapse ) {
 
                 # strip \s from before us
                 $output =~ s/ \s+ \z //x;
@@ -81,7 +82,7 @@ sub process {
             my $tag      = $token->get_tag;
             my $prev_tag = $iter->prev_tag_name;
 
-            if ( any { $tag eq $_ } @collapse ) {
+            if ( grep { $tag eq $_ } @collapse ) {
 
                 # strip \s from before us
                 $output =~ s/ \s+ \z //x;
@@ -99,7 +100,7 @@ sub process {
 
         my $prev_tag = $iter->prev_tag_name;
 
-        if ( defined $prev_tag && any { $prev_tag eq $_ } @collapse ) {
+        if ( defined $prev_tag && grep { $prev_tag eq $_ } @collapse ) {
             $output =~ s/ \s+ \z //x;
 
             my $part = $token->as_is;
@@ -116,17 +117,13 @@ sub process {
     return $output;
 }
 
-__PACKAGE__->meta->make_immutable;
-
-
 package HTML::FormFu::OutputProcessor::StripWhitespace::_iter;
-use Moose;
 
 sub new {
-    my ( $class, @tags ) = @_;
+    my $class = shift;
 
     my %self = (
-        tags => \@tags,
+        tags => \@_,
         i    => 0,
     );
 
@@ -156,7 +153,39 @@ sub prev_tag_name {
     }
 }
 
-__PACKAGE__->meta->make_immutable( inline_constructor => 0 );
+#sub prev_start_tag_name {
+#    my ($self) = @_;
+#
+#    my $i = $self->{i} - 2;
+#
+#    while ( $i >= 0) {
+#
+#        if ( $self->{tags}[$i]->is_tag ) {
+#            return if ! $self->{tags}[$i]->is_start_tag;
+#
+#            return $self->{tags}[$i]->get_tag;
+#        }
+#
+#        --$i;
+#    }
+#}
+#
+#sub prev_end_tag_name {
+#    my ($self) = @_;
+#
+#    my $i = $self->{i} - 2;
+#
+#    while ( $i >= 0) {
+#
+#        if ( $self->{tags}[$i]->is_tag ) {
+#            return if ! $self->{tags}[$i]->is_end_tag;
+#
+#            return $self->{tags}[$i]->get_tag;
+#        }
+#
+#        --$i;
+#    }
+#}
 
 1;
 
@@ -182,7 +211,7 @@ HTML::FormFu::OutputProcessor::StripWhitespace - Strip shitespace from HTML outp
 
 Is a sub-class of, and inherits methods from L<HTML::FormFu::OutputProcessor>
 
-L<HTML::FormFu>
+L<HTML::FormFu::FormFu>
 
 =head1 AUTHOR
 
@@ -192,5 +221,3 @@ Carl Franks C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
-
-=cut
